/*
Theme Name: UX Shop
Theme URI: https://themes.develoved.com/uxshop/
Author: Develoved
Author URI: https://themes.develoved.com
Description: A premium WooCommerce theme designed and develoved from the ground up with the sole purpose of helping you create an astonishing, beautiful and super user friendly website that will boost your products sales.
Version: 1.7.3
License: GNU General Public License
License URI: see license.txt
Text Domain: ux-shop
Tags: one-column, two-columns, right-sidebar, left-sidebar, custom-background, custom-header, theme-options, full-width-template, featured-images, flexible-header, custom-menu, translation-ready
*/
